@@ -9,8 +9,8 @@
 
 ;; Maintainer: Campbell Barton <ideasman42@gmail.com>
 ;; Keywords: convenience
-;; Package-Version: 20251101.1223
-;; Package-Revision: f7a9f76aca93
+;; Package-Version: 20251126.529
+;; Package-Revision: 7efdeecb1eff
 ;; URL: https://codeberg.org/ideasman42/emacs-repeat-fu
 ;; Package-Requires: ((emacs "29.1"))
 
@@ -203,7 +203,7 @@ The :post-data callback in `repeat-fu-backend' may use it.")
           (ring-capacity (length buf)))
 
 
-      (unless (and (not (zerop len))
+      (unless (and (null (zerop len))
                    (let ((num-and-elem (aref buf pos)))
                      (cond
                       ((equal elem (cdr num-and-elem))
